@@ -87,7 +87,7 @@ do
 done
 
 
-nohup ${JBOSS_HOME}/bin/run_hinemos.sh ${ALL_OPTION} -b ${IP_ADDRESS} > ${HINEMOS_HOME}/var/log/jboss_stdout.log &
+nohup ${JBOSS_HOME}/bin/run_hinemos.sh ${ALL_OPTION} -b ${IP_ADDRESS} > ${HINEMOS_HOME}/var/log/jboss_stdout.log 2>&1 &
 
 TODAY=`date +%Y-%m-%d`
 TIME_COUNT=0
