@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) 2006 - 2008 NTT DATA Corporation
+#Copyright (C) since 2006 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -24,6 +24,8 @@ if [ $EXEC_USER != "root" ]; then
 	exit
 fi
 
+#locale情報を設定
+LOCALE=ja_JP.UTF-8
 
 ##
 ## カーネルリソースの確認
@@ -311,14 +313,15 @@ do
 			# /opt/hinemos以下にコピー
 			echo "必要なファイルをインストールディレクトリにコピーします。"
 			cp -pr ${EXEC_PATH}/hinemos /opt
+			cp -pr ${EXEC_PATH}/manager_uninstaller* ${HINEMOS_HOME}/sbin
+			cp -pr ${EXEC_PATH}/install.cfg ${HINEMOS_HOME}/sbin
 			
 			# 一括制御の設定
 			crun_setting
 			
 			#インストールディレクトリに応じて各設定ファイルを変更
 			REPLACE_PATH=`echo ${HINEMOS_HOME} | sed 's/\//\\\\\//g'`
-#			sed -e "s/%%hinemos_install_dir%%/${REPLACE_PATH}/" -e "s/%%jre_name%%/${JRE_NAME}/" -e "s/%%ip_address%%/${IP_ADDRESS}/" -e "s/%%hinemos_ftp_host%%/${FTP_SERVER}/" ${EXEC_PATH}/hinemos.cfg > ${HINEMOS_HOME}/hinemos.cfg
-			sed -e "s/%%hinemos_install_dir%%/${REPLACE_PATH}/" -e "s/%%jre_name%%/${JRE_NAME}/" -e "s/%%ip_address%%/${IP_ADDRESS}/" ${EXEC_PATH}/hinemos.cfg > ${HINEMOS_HOME}/hinemos.cfg
+			sed -e "s/%%hinemos_install_dir%%/${REPLACE_PATH}/" -e "s/%%jre_name%%/${JRE_NAME}/" -e "s/%%ip_address%%/${IP_ADDRESS}/" -e "s/%%locale%%/${LOCALE}/" ${EXEC_PATH}/hinemos.cfg > ${HINEMOS_HOME}/hinemos.cfg
 			sed -e "s/%%ip_address%%/${IP_ADDRESS}/" ${EXEC_PATH}/hinemos/lib/syslogforward/LogForward.properties > ${HINEMOS_HOME}/lib/syslogforward/LogForward.properties
 			
 			echo "必要なファイルのコピーが終了しました。"
